# csr_azure_utils
=================

# Description of modules and their intent: 

#### General Utility Modules
* azure_utils
* blob_utils
* meta_utils
* metric_utils
* eventhub_utils
* file_utils
* general_utils

#### Cloud Abstraction Modules
* csr_cloud

#### Module for High Availability
* ha_azure

#### Module for Autoscaler
* as_azure

#### Modules for Managing Active Directory Applications
* aad_auth
* auth_mgr
* clear_aad_application_list
* clear_default_aad_app
* set_default_aad_app
* show_auth_applications

#### Modules for Managed Identity
* msi_auth

#### Modules for Authentication Token Management
* token_api
* token_svr
* clear_token
* refresh_token 

## CI status
[![Build and Test Status]( https://engci-private-rtp.cisco.com/jenkins/ent-routing/job/CSR/job/csr_azure_utils_postmerge/badge/icon)]( https://engci-private-rtp.cisco.com/jenkins/ent-routing/job/CSR/job/csr_azure_utils_postmerge)


